#
# spec file for package python-policyd-spf
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python-policyd-spf
Version:        1.3.2
Release:        2.1
Summary:        A pure-Python Postfix policy daemon for SPF checking
License:        Apache-2.0
Group:          Development/Libraries/Python
Url:            https://launchpad.net/pypolicyd-spf
Source:         pypolicyd-spf-%{version}.tar.gz
BuildRequires:  python-devel >= 2.5
BuildRequires:  python-setuptools
BuildRequires:  python-ipaddr >= 2.1.10
BuildRequires:  python-pyspf >= 2.0.7
Requires:       postfix >= 2.1
Requires:       python-pyspf >= 2.0.7
# required for "Header_Type = AR", but gives no helpful error message
Recommends:     python-authres
# note: for Python 3, this is optional as ipaddress module is used
Requires:       python-ipaddr >= 2.1.10
BuildRoot:      %{_tmppath}/%{name}-%{version}-buildroot
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
%if 0%{?rhel_version} && 0%{?rhel_version} <= 600
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
%if 0%{?centos_version} && 0%{?centos_version} <= 600
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
%endif
%endif

%description
python-policyd-spf is a Postfix policy engine for Sender Policy
Framework (SPF) checking. It is implemented in pure Python and uses
the python-spf (pyspf) module.

This SPF policy server implementation provides flexible options for
different receiver policies and sender whitelisting to enable it to
support a very wide range of requirements. As of version 1.3 changes
in the standards track update to SPF, RFC 7208 are all incorporated.

The SPF website is http://www.openspf.org/.

The Postfix configuration must be changed to check SPF.
See man 1 python-policyd-spf for details.

%prep
%setup -q -n pypolicyd-spf-%{version}
# remove Python 3 shebang
sed -i '1s/python3/python/' policyd-spf
# use the commented config file
mv policyd-spf.conf.commented policyd-spf.conf

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc README README.per_user_whitelisting COPYING CHANGES
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/policyd-spf.conf
%{_bindir}/policyd-spf
%{_mandir}/man?/*
%{python_sitelib}/*

%changelog
* Mon May  2 2016 opensuse@dstoecker.de
- add python-authres as recommended package
* Sat Nov  7 2015 opensuse@mirell.de
- Update to version 1.3.2:
  + Fix python3 incompatibility in cases where HELO name is
    somehow missing (LP: #1184102)
  + Updated README to mention the minimum ipaddr version,
    if needed, is 2.1.10 (LP: #1229862)
  + Fix up header caching (LP: #1422325)
  + Fix and refactor for simplicity detection of Authserv_Id
    missing from configuration (LP: #1484239)
  + Add try/except around SPF record queries of No_Mail option to
    avoid errors on bogus TXT records
- Changes from version 1.3.1:
  + Fix case where, when run with python3 the policy server would
    choke on email addresses that contained non-ascii characters
    (LP: #1325579)
- Changes from version 1.3:
  + Updates related to the new SPF RFC, RFC 7208
  - Added new config option, Lookup_Time, to adjust SPF record
    timeout limit (default 20 seconds per RFC 7208)
    Requires at least pyspf 2.0.7
  - Added new config option, Void_Limit, to enable the new void
    lookup limit instroduced in RFC 7208 to be adjusted -
    Default is 2 as recommended in RFC 7208, section 4.6.4.
    Has no effect on pyspf before 2.0.9.
  - Updated documentation to refer to RFC 7208 (and RFC 7001 for
    authentication results)
  - Updated descriptions in documentation to describe spec
    compliance relative to RFC 7208 instead of RFC 4408
  + Guard against crashes when forming header field contents if
    the receiver is somehow missing
- Changes from version 1.2:
  + Added external dependency on ipaddr module for python versions
    < 3.3
  + Fix PTR whitelist to work with IPv6 connections (patch from
    Frank Hunszinger) - LP: #1179266
  + Replace custom code with use of ipaddr/ipaddress to perform
    CIDR matching
  + CIDR network definitions are now more limited to correct
    networks
  - Double slashes are no longer allowed
  - Updated defaults and documentation for skip_addresses to
    match
- Changes from version 1.1.2 (2013-05-10 1:
    Brown paper bag release
  + Add MANIFEST.in and rename in setup.py to make package
    compatible with using sdist (fixes missing files in 1.1.1)
- Changes from version 1.1.1 (2013-05-10 1:
  + Fixed documentation to be more compatible with running with
    Python3.
- Changes from version 1.1 (2012-07-21 2:
  + Ported to Python 3. Tested on python3.2, python2.7, and
    python2.6. Versions previous to python2.6 will not work.
* Mon Apr  2 2012 gerberb@zenez.com
- Add SuSE specific spec file changes
- Updated to version 1.0:
  + Fixed missing authentication results headers for no
    authentication performed cases (when authres is enabled)
  + Fixed ambiguous config file warning in per user processing
  + Make functions private (leading underscore)
  + Fixed erroneous use of syslog.LOG_ERR in per user processing
- License changed from GPL 2 to Apache 2.0
- Changes from version 0.9:
  + Add support for optionally generating RFC 5451 authentication
    results headers
  + Add new Header_Type configuration option to support generating
    RFC 4408 Received-SPF and/or RFC 5451 Authentication-Results
    headers (default is Received-SPF)
  + Changed license from GPL version 2 to Apache 2.0 with
    agreement from all copyright holders
  + Log message to the error facility for all OSErrors
  + Instead of crashing if per user configuration is missing,
    continue with global configuration
  + Use openspf.net instead of openspf.org for Why text in
    reject/defer messages due to extended openspf.org downtime
  + Fix install location of standard config file when installed
    with distutils
  + Fix example syntax in policyd-spf.peruser.5
  + Update and clarify inconsistencies in policyd-spf.conf.5
- Changes from version 0.8.1:
  + Prepend headers even when defaultSeedOnly = 0 (now does what's
    documented)
  + Fix typos in policyd-spf.conf(5)
- Changes from version 0.8:
  + Add Domain_Whitelist_PTR to allow whitelisting from SPF tests
    based on rDNS PTR match (patch from Colin Stewart
    <colin@owlfish.com>)
  + Only check Domain_Whitelist if it actually exists in the
    configuration
  + Add No_Mail option to allow for only rejecting from
    hosts/domains that send no mail ("v=spf1 -all")
  + Add ability to provide per user (per recipient) settings
  + Fixed a bug so that skipping SPF checks due to localhost or
    any whitelist settings does not prepend multiple headers per
    message for multi recipient messages
  + Fixed a bug so that non-reject HELO results are correctly
    used when Mail From checks are disabled (No_Check)
  + Clean up unused code in policydspfsupp.py
- Changes from version 0.7.3:
  + No longer require Python 2.5 (Thanks to Matthew Munsey
    <openspf@msm.unending.org>)
  + Update copyright for new year
  + Update for new project location
  + Clean up imports (PEP-8 style, remove redundancy, removed
    unused)
  + Remove deprecated licence distribution option from setup.py
- Changes from version 0.7.2:
  + Require at least Python 2.5
  + Fix to not crash on invalid senders that lack a domain part
  + Remove unused imports of deprecated popen2 module
* Fri Aug 15 2008 gerberb@zenez.com
- Updated to version 0.7.1:
  + Fix default log level in policyd-spf.conf.commented to match
    default
  + Update configuration recommendations in policyd-spf.1
